@@ -1,4 +1,5 @@
 from toolz import curry
+from ramda.is_empty import is_empty
 
 
 @curry
@@ -6,6 +7,9 @@ def group_with(predicate, xs):
     """Takes a list and returns a list of lists where each sublist's elements are
     all satisfied pairwise comparison according to the provided function.
     Only adjacent elements are passed to the comparison function"""
+    if is_empty(xs):
+        return []
+
     out = []
     is_str = isinstance(xs, str)
     group = [xs[0]]
