@@ -2,7 +2,7 @@ from toolz import curry
 
 
 @curry
-def gt(y, x):
+def gt(x, y):
     """Returns true if the first argument is greater than the second; false
     otherwise"""
     return x > y
