@@ -1,7 +1,7 @@
 from ramda import *
 from ramda.private.asserts import *
 
-path_components = split("/")
+path_components = split("\/")
 
 
 def test_split():
@@ -9,4 +9,6 @@ def test_split():
         tail(path_components("/usr/local/bin/node")), ["usr", "local", "bin", "node"]
     )
 
-    assert_equal(split(".", "a.b.c.xyz.d"), ["a", "b", "c", "xyz", "d"])
+    assert_equal(split("\.", "a.b.c.xyz.d"), ["a", "b", "c", "xyz", "d"])
+
+    assert_equal(split("\s+", "a b c    xyz  d"), ["a", "b", "c", "xyz", "d"])
